# Security Policy

Mozilla has a [well-defined process for handling security vulnerabilities](https://www.mozilla.org/en-US/about/governance/policies/security-group/bugs/) based around responsible disclosure.

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 15.x.x  | :white_check_mark: |
| < 15.0  | :x:                |

## Reporting a Vulnerability

If you believe you have found a Kinto-related security vulnerability, you should visit the [Mozilla bug bounty program](https://www.mozilla.org/en-US/security/bug-bounty/) for information on how to submit them.

[This Bugzilla template](https://bugzilla.mozilla.org/enter_bug.cgi?assigned_to=mathieu%40mozilla.com&bug_ignored=0&bug_severity=--&bug_status=NEW&cf_fx_iteration=---&cf_fx_points=---&cf_status_firefox94=---&cf_status_firefox95=---&cf_status_firefox96=---&cf_status_firefox_esr91=---&cf_tracking_firefox94=---&cf_tracking_firefox95=---&cf_tracking_firefox96=---&cf_tracking_firefox_esr91=---&cf_tracking_firefox_relnote=---&cf_tracking_firefox_sumo=---&component=Server%3A%20Remote%20Settings&contenttypemethod=list&contenttypeselection=text%2Fplain&defined_groups=1&filed_via=standard_form&flag_type-37=X&flag_type-607=X&flag_type-708=X&flag_type-721=X&flag_type-737=X&flag_type-748=X&flag_type-787=X&flag_type-800=X&flag_type-803=X&flag_type-846=X&flag_type-864=X&flag_type-936=X&flag_type-947=X&form_name=enter_bug&groups=cloud-services-security&maketemplate=Remember%20values%20as%20bookmarkable%20template&op_sys=Unspecified&priority=--&product=Cloud%20Services&rep_platform=Unspecified&target_milestone=---&version=unspecified) will help you file a security vulnerability directly against Kinto (Remote Settings at Mozilla).
